==> 0.0.6.tar.gz: lib/component/image_upload_view.dart <==
import 'package:flutter/material.dart';
import 'package:vone_ipfs/bean/upload_result_entity.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/component/multiple_image_view.dart';
import 'package:vone_ipfs/component/single_image_view.dart';
import 'package:vone_ipfs/component/vone_image.dart';

class ImageUploadPage extends StatefulWidget {
  ///图片的宽度
  final double imageWidth;

  ///图片高度
  final double imageHeight;

  ///已有的图片列表
  final List<UploadResultEntity> images;

  ///图片形状
  final ImageShape shape;

  ///上传模式 默认多文件上传
  final UploadMode uploadMode;

  ///上传成功的回调
  final ValueChanged<List<UploadResultEntity>>? valueChangedCallback;

  ///添加图片的按钮
  final Widget? addImageWidget;

  /// 添加图片按钮的位置
  final UploadBtnPosition btnPosition;
  final int itemCount;
  final String dirId;

  ImageUploadPage(
      {Key? key,
      this.imageWidth = 110,
      this.imageHeight = 110,
      required this.images,
      required this.dirId,
      this.uploadMode = UploadMode.MULTIPLE,
      this.valueChangedCallback,
      this.addImageWidget,
      this.itemCount = 3,
      this.btnPosition = UploadBtnPosition.RIGHT,
      this.shape = ImageShape.None})
      : super(key: key);

  @override
  ImageUploadPageState createState() => new ImageUploadPageState();
}

class ImageUploadPageState extends State<ImageUploadPage> {
  @override
  Widget build(BuildContext context) {
    if (widget.uploadMode == UploadMode.SINGLE) {
      return SingleImageView(
          imageWidth: widget.imageWidth,
          imageHeight: widget.imageHeight,
          shape: widget.shape,
          imageEntity: widget.images.isNotEmpty?widget.images[0]:null,
          singleCallback: (value) {
            if (widget.valueChangedCallback != null) {
              widget.valueChangedCallback!([value]);
            }
          });
    } else {
      return MultipleImageView(
        images: widget.images,
        imageWidth: widget.imageWidth,
        imageHeight: widget.imageHeight,
        addImageWidget: widget.addImageWidget,
        itemCount: widget.itemCount,
        btnPosition: widget.btnPosition,
        shape: widget.shape,
        dirId: widget.dirId,
        valueChangedCallback: widget.valueChangedCallback,
      );
    }
  }

  @override
  void initState() {
    super.initState();
  }
}

==> 0.0.8.tar.gz: lib/component/image_upload_view.dart <==
import 'package:flutter/material.dart';
import 'package:vone_ipfs/bean/upload_result_entity.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/component/multiple_image_view.dart';
import 'package:vone_ipfs/component/single_image_view.dart';
import 'package:vone_ipfs/component/vone_image.dart';

class ImageUploadView extends StatefulWidget {
  ///图片的宽度
  final double imageWidth;

  ///图片高度
  final double imageHeight;

  ///已有的图片列表
  final List<UploadResultEntity> images;

  ///图片形状
  final ImageShape shape;

  ///上传模式 默认多文件上传
  final UploadMode uploadMode;

  ///上传成功的回调
  final ValueChanged<List<UploadResultEntity>>? valueChangedCallback;

  ///添加图片的按钮
  final Widget? addImageWidget;

  /// 添加图片按钮的位置
  final UploadBtnPosition btnPosition;
  final int itemCount;
  final String dirId;
  final String dirName;
  final String placeholder;
  bool isFixedDir;

  ImageUploadView(
      {Key? key,
      this.imageWidth = 110,
      this.imageHeight = 110,
      required this.images,
      required this.dirId,
      required this.dirName,
      this.isFixedDir = false,
      this.uploadMode = UploadMode.MULTIPLE,
      this.valueChangedCallback,
      this.addImageWidget,
      this.itemCount = 3,
      this.placeholder = '',
      this.btnPosition = UploadBtnPosition.RIGHT,
      this.shape = ImageShape.None})
      : super(key: key);

  @override
  ImageUploadViewState createState() => ImageUploadViewState();
}

class ImageUploadViewState extends State<ImageUploadView> {
  @override
  Widget build(BuildContext context) {
    if (widget.uploadMode == UploadMode.SINGLE) {
      return SingleImageView(
          dirId: widget.dirId,
          dirName: widget.dirName,
          isFixedDir: widget.isFixedDir,
          imageWidth: widget.imageWidth,
          imageHeight: widget.imageHeight,
          shape: widget.shape,
          addImageWidget: widget.addImageWidget,
          imageEntity: widget.images.isNotEmpty ? widget.images[0] : null,
          singleCallback: (value) {
            if (widget.valueChangedCallback != null) {
              widget.valueChangedCallback!([value]);
            }
          });
    } else {
      return MultipleImageView(
        images: widget.images,
        imageWidth: widget.imageWidth,
        imageHeight: widget.imageHeight,
        addImageWidget: widget.addImageWidget,
        itemCount: widget.itemCount,
        btnPosition: widget.btnPosition,
        shape: widget.shape,
        dirId: widget.dirId,
        dirName: widget.dirName,
        isFixedDir: widget.isFixedDir,
        valueChangedCallback: widget.valueChangedCallback,
      );
    }
  }

  @override
  void initState() {
    super.initState();
  }
}
